==> idris-1.0-43-i686.pkg.tar.xz: usr/share/haskell/register/idris.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: idris
version: 1.0
id: idris-1.0-I2zfpLZT6nt5UVEaju96qZ
key: idris-1.0-I2zfpLZT6nt5UVEaju96qZ
license: BSD3
maintainer: Edwin Brady <eb@cs.st-andrews.ac.uk>
stability: Beta
homepage: http://www.idris-lang.org/
synopsis: Functional Programming Language with Dependent Types
description:
    Idris is a general purpose language with full dependent types.
    It is compiled, with eager evaluation.
    Dependent types allow types to be predicated on values,
    meaning that some aspects of a program'\''s behaviour can be
    specified precisely in the type. The language is closely
    related to Epigram and Agda. There is a tutorial at
    <http://www.idris-lang.org/documentation>.
    Features include:
    .
    * Full, first class, dependent types with dependent pattern matching
    .
    * where clauses, with rule, case expressions,
    pattern matching let and lambda bindings
    .
    * Interfaces (similar to type classes), monad comprehensions
    .
    * do notation, idiom brackets, syntactic conveniences for lists,
    tuples, dependent pairs
    .
    * Totality checking
    .
    * Coinductive types
    .
    * Indentation significant syntax, extensible syntax
    .
    * Cumulative universes
    .
    * Simple foreign function interface (to C)
    .
    * Hugs style interactive environment
category: Compilers/Interpreters, Dependent Types
author: Edwin Brady
exposed: True
exposed-modules:
    Idris.Core.Binary Idris.Core.CaseTree Idris.Core.Constraints
    Idris.Core.DeepSeq Idris.Core.Elaborate Idris.Core.Evaluate
    Idris.Core.Execute Idris.Core.ProofState Idris.Core.ProofTerm
    Idris.Core.TT Idris.Core.Typecheck Idris.Core.Unify Idris.Core.WHNF
    Idris.Elab.Utils Idris.Elab.Type Idris.Elab.AsPat Idris.Elab.Clause
    Idris.Elab.Data Idris.Elab.Record Idris.Elab.Interface
    Idris.Elab.Implementation Idris.Elab.Provider Idris.Elab.RunElab
    Idris.Elab.Transform Idris.Elab.Value Idris.Elab.Term
    Idris.Elab.Quasiquote Idris.Elab.Rewrite Idris.REPL.Browse
    Idris.AbsSyntax Idris.AbsSyntaxTree Idris.Apropos Idris.ASTUtils
    Idris.CaseSplit Idris.Chaser Idris.Colours Idris.Completion
    Idris.Coverage Idris.DSL Idris.DataOpts Idris.DeepSeq
    Idris.Delaborate Idris.Directives Idris.Docs Idris.Docstrings
    Idris.ElabDecls Idris.Erasure Idris.Error Idris.ErrReverse
    Idris.Help Idris.IBC Idris.IdeMode Idris.IdrisDoc Idris.Imports
    Idris.Info Idris.Info.Show Idris.Inliner Idris.Interactive
    Idris.Output Idris.Main Idris.ModeCommon Idris.Parser
    Idris.Parser.Helpers Idris.Parser.Ops Idris.Parser.Expr
    Idris.Parser.Data Idris.PartialEval Idris.Primitives
    Idris.ProofSearch Idris.Prover Idris.Providers Idris.Reflection
    Idris.REPL Idris.REPL.Parser Idris.REPL.Commands Idris.Termination
    Idris.Transforms Idris.TypeSearch Idris.Unlit Idris.WhoCalls
    Idris.CmdOptions IRTS.BCImp IRTS.Bytecode IRTS.CodegenC
    IRTS.CodegenCommon IRTS.CodegenJavaScript IRTS.Exports
    IRTS.JavaScript.AST IRTS.Compiler IRTS.Defunctionalise IRTS.DumpBC
    IRTS.Inliner IRTS.Lang IRTS.LangOpts IRTS.Portable IRTS.Simplified
    IRTS.System Idris.Package Idris.Package.Common Util.DynamicLinker
    Util.ScreenSize Util.System
hidden-modules: Util.Pretty Util.Net Idris.Package.Parser
                Paths_idris Version_idris Tools_idris
abi: f7811e075e23bffc74566aa9c455b8f3
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/idris-1.0
library-dirs: /usr/lib/ghc-8.0.2/site-local/idris-1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/idris
hs-libraries: HSidris-1.0-I2zfpLZT6nt5UVEaju96qZ
extra-libraries:
    gmp
depends:
    aeson-1.1.2.0-2Tms2Hc2yE36x3yS5aZqW9
    annotated-wl-pprint-0.7.0-3FrdG13wTO5J8qYXtEBG3s
    ansi-terminal-0.6.3.1-59sjf9WqHYuFAo9gQw9Bhp
    ansi-wl-pprint-0.6.7.3-7jqnIfTUHr2Bkg0VIWs8Q5 array-0.5.1.1
    async-2.1.1.1-2GwQEYzLBsdIBCHbNA3HGy base-4.9.1.0
    base64-bytestring-1.0.0.1-4O9TExPPz6eI82Yj7L4SIj binary-0.8.3.0
    blaze-html-0.8.1.3-EHw0sCLFL6JKZx2lFkE5O8
    blaze-markup-0.7.1.1-Amik95gvtJH76XeEGEdOV0 bytestring-0.10.8.1
    cheapskate-0.1.0.5-KVVuRIvNAnF1HA4xCATntq
    code-page-0.1.3-Fxfj8KlZt5M4CQMDwRDd5i containers-0.5.7.1
    deepseq-1.4.2.0 directory-1.3.0.0 filepath-1.4.1.1
    fingertree-0.1.1.0-Aiaf912zjZGHvH3XyjxrYA
    fsnotify-0.2.1-5DjHEI2ebLX5pCQ15CBX6S haskeline-0.7.3.0
    ieee754-0.8.0-CDXZC1OkvI520r7z7XGrZG
    libffi-0.1-1byXGcdzpX5Bu9vSOoYA5k mtl-2.2.1-BLKBelFsPB3BoFeSWSOYj6
    network-2.6.3.2-IsLM4TXcLoRI0fmmBYVyQz
    optparse-applicative-0.13.2.0-ATtPSoVb5QO98rs9Fb1xKb
    parsers-0.12.5-FBiee1ATP2DJ3uofdpH32r pretty-1.1.3.3
    process-1.4.3.0 regex-tdfa-1.2.2-JFeutuWiS2vGBM4qXQlqio
    safe-0.3.15-2Yd45VWFfdcKqKyispOifY
    split-0.2.3.2-CJl40zTyCIV16Pr60nb7CT
    terminal-size-0.3.2.1-LL700oIgYTEEtJWQuzY2Y4
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq time-1.6.0.1
    transformers-0.5.2.0
    transformers-compat-0.5.1.4-IuFogs8HAVUJBWVNMhtssu
    trifecta-1.6.2.1-JZpCvmlSeAXI03TKV8kL4T
    uniplate-1.6.12-BnRcpBOCdUXBfQOzOuZrJE unix-2.7.2.1
    unordered-containers-0.2.8.0-1tqMF698WJE3INvmpuzQZc
    utf8-string-1.0.1.1-1DpjxLeTvGg7ttZZojxJR5
    vector-0.12.0.1-692PQMDMB6pIQ1uGwefDcQ
    vector-binary-instances-0.2.3.5-Do2uVjLEGQcAMYmorIf1G3
    zip-archive-0.3.1.1-CTnIdx1PD2R28s6Hv1Ft3y
haddock-interfaces: /usr/share/doc/idris/html/idris.haddock
haddock-html: /usr/share/doc/idris/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> idris-1.0-45-i686.pkg.tar.xz: usr/share/haskell/register/idris.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: idris
version: 1.0
id: idris-1.0-AhzFHyMpjVK9jY0cFJjTN5
key: idris-1.0-AhzFHyMpjVK9jY0cFJjTN5
license: BSD3
maintainer: Edwin Brady <eb@cs.st-andrews.ac.uk>
stability: Beta
homepage: http://www.idris-lang.org/
synopsis: Functional Programming Language with Dependent Types
description:
    Idris is a general purpose language with full dependent types.
    It is compiled, with eager evaluation.
    Dependent types allow types to be predicated on values,
    meaning that some aspects of a program'\''s behaviour can be
    specified precisely in the type. The language is closely
    related to Epigram and Agda. There is a tutorial at
    <http://www.idris-lang.org/documentation>.
    Features include:
    .
    * Full, first class, dependent types with dependent pattern matching
    .
    * where clauses, with rule, case expressions,
    pattern matching let and lambda bindings
    .
    * Interfaces (similar to type classes), monad comprehensions
    .
    * do notation, idiom brackets, syntactic conveniences for lists,
    tuples, dependent pairs
    .
    * Totality checking
    .
    * Coinductive types
    .
    * Indentation significant syntax, extensible syntax
    .
    * Cumulative universes
    .
    * Simple foreign function interface (to C)
    .
    * Hugs style interactive environment
category: Compilers/Interpreters, Dependent Types
author: Edwin Brady
exposed: True
exposed-modules:
    Idris.Core.Binary Idris.Core.CaseTree Idris.Core.Constraints
    Idris.Core.DeepSeq Idris.Core.Elaborate Idris.Core.Evaluate
    Idris.Core.Execute Idris.Core.ProofState Idris.Core.ProofTerm
    Idris.Core.TT Idris.Core.Typecheck Idris.Core.Unify Idris.Core.WHNF
    Idris.Elab.Utils Idris.Elab.Type Idris.Elab.AsPat Idris.Elab.Clause
    Idris.Elab.Data Idris.Elab.Record Idris.Elab.Interface
    Idris.Elab.Implementation Idris.Elab.Provider Idris.Elab.RunElab
    Idris.Elab.Transform Idris.Elab.Value Idris.Elab.Term
    Idris.Elab.Quasiquote Idris.Elab.Rewrite Idris.REPL.Browse
    Idris.AbsSyntax Idris.AbsSyntaxTree Idris.Apropos Idris.ASTUtils
    Idris.CaseSplit Idris.Chaser Idris.Colours Idris.Completion
    Idris.Coverage Idris.DSL Idris.DataOpts Idris.DeepSeq
    Idris.Delaborate Idris.Directives Idris.Docs Idris.Docstrings
    Idris.ElabDecls Idris.Erasure Idris.Error Idris.ErrReverse
    Idris.Help Idris.IBC Idris.IdeMode Idris.IdrisDoc Idris.Imports
    Idris.Info Idris.Info.Show Idris.Inliner Idris.Interactive
    Idris.Output Idris.Main Idris.ModeCommon Idris.Parser
    Idris.Parser.Helpers Idris.Parser.Ops Idris.Parser.Expr
    Idris.Parser.Data Idris.PartialEval Idris.Primitives
    Idris.ProofSearch Idris.Prover Idris.Providers Idris.Reflection
    Idris.REPL Idris.REPL.Parser Idris.REPL.Commands Idris.Termination
    Idris.Transforms Idris.TypeSearch Idris.Unlit Idris.WhoCalls
    Idris.CmdOptions IRTS.BCImp IRTS.Bytecode IRTS.CodegenC
    IRTS.CodegenCommon IRTS.CodegenJavaScript IRTS.Exports
    IRTS.JavaScript.AST IRTS.Compiler IRTS.Defunctionalise IRTS.DumpBC
    IRTS.Inliner IRTS.Lang IRTS.LangOpts IRTS.Portable IRTS.Simplified
    IRTS.System Idris.Package Idris.Package.Common Util.DynamicLinker
    Util.ScreenSize Util.System
hidden-modules: Util.Pretty Util.Net Idris.Package.Parser
                Paths_idris Version_idris Tools_idris
abi: fb0dfa33d3fbd8068f6f74f9ff7541d3
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/idris-1.0
library-dirs: /usr/lib/ghc-8.0.2/site-local/idris-1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/idris
hs-libraries: HSidris-1.0-AhzFHyMpjVK9jY0cFJjTN5
extra-libraries:
    gmp
depends:
    aeson-1.1.2.0-3Yc3xmkAyKHC7Vn5OXDFOk
    annotated-wl-pprint-0.7.0-3FrdG13wTO5J8qYXtEBG3s
    ansi-terminal-0.6.3.1-59sjf9WqHYuFAo9gQw9Bhp
    ansi-wl-pprint-0.6.7.3-7jqnIfTUHr2Bkg0VIWs8Q5 array-0.5.1.1
    async-2.1.1.1-2GwQEYzLBsdIBCHbNA3HGy base-4.9.1.0
    base64-bytestring-1.0.0.1-4O9TExPPz6eI82Yj7L4SIj binary-0.8.3.0
    blaze-html-0.8.1.3-EHw0sCLFL6JKZx2lFkE5O8
    blaze-markup-0.7.1.1-Amik95gvtJH76XeEGEdOV0 bytestring-0.10.8.1
    cheapskate-0.1.0.5-KV6DmPwqe36ESre8KtKsqW
    code-page-0.1.3-Fxfj8KlZt5M4CQMDwRDd5i containers-0.5.7.1
    deepseq-1.4.2.0 directory-1.3.0.0 filepath-1.4.1.1
    fingertree-0.1.1.0-Aiaf912zjZGHvH3XyjxrYA
    fsnotify-0.2.1-5DjHEI2ebLX5pCQ15CBX6S haskeline-0.7.3.0
    ieee754-0.8.0-CDXZC1OkvI520r7z7XGrZG
    libffi-0.1-1byXGcdzpX5Bu9vSOoYA5k mtl-2.2.1-BLKBelFsPB3BoFeSWSOYj6
    network-2.6.3.2-IsLM4TXcLoRI0fmmBYVyQz
    optparse-applicative-0.13.2.0-ATtPSoVb5QO98rs9Fb1xKb
    parsers-0.12.5-AXzq17gNTfCKs6hv5mWVL8 pretty-1.1.3.3
    process-1.4.3.0 regex-tdfa-1.2.2-JFeutuWiS2vGBM4qXQlqio
    safe-0.3.15-2Yd45VWFfdcKqKyispOifY
    split-0.2.3.2-CJl40zTyCIV16Pr60nb7CT
    terminal-size-0.3.2.1-LL700oIgYTEEtJWQuzY2Y4
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq time-1.6.0.1
    transformers-0.5.2.0
    transformers-compat-0.5.1.4-IuFogs8HAVUJBWVNMhtssu
    trifecta-1.6.2.1-AmrK23tqKy5Hy8lmwHwsWK
    uniplate-1.6.12-BnRcpBOCdUXBfQOzOuZrJE unix-2.7.2.1
    unordered-containers-0.2.8.0-1tqMF698WJE3INvmpuzQZc
    utf8-string-1.0.1.1-1DpjxLeTvGg7ttZZojxJR5
    vector-0.12.0.1-692PQMDMB6pIQ1uGwefDcQ
    vector-binary-instances-0.2.3.5-Do2uVjLEGQcAMYmorIf1G3
    zip-archive-0.3.1.1-CTnIdx1PD2R28s6Hv1Ft3y
haddock-interfaces: /usr/share/doc/idris/html/idris.haddock
haddock-html: /usr/share/doc/idris/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
